netapp_ontap.resources.security_saml_def_metadata API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.security_saml_def_metadata`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

This API is used to manage relevant information about the SAML default metadata configuration in the cluster. The POST request creates a SAML default metadata configuration if there is none present. The DELETE request removes the SAML default metadata configuration. Various responses are shown in the examples below.

## Examples

### Retrieving the SAML default metadata configuration in the cluster

The following output shows the SAML default metadata configuration in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlDefMetadata

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlDefMetadata()
        resource.get()
        print(resource)

Try it out

    SecuritySamlDefMetadata(
        {
            "scope": "cluster",
            "_links": {
                "self": {
                    "href": "/api/security/authentication/cluster/saml-sp/default-metadata"
                }
            },
            "host": "172.21.74.181",
            "certificate": {
                "ca": "cluster-1",
                "serial_number": "180E3331A0DC5A19",
                "common_name": "cluster-1",
            },
        }
    )

### Creating the SAML default metadata configuration in the cluster

The following output shows how to create the SAML default metadata in the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlDefMetadata

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlDefMetadata()
        resource.host = "172.21.74.181"
        resource.certificate = {"ca": "cluster1", "serial_number": "156F10C3EB4C51C1"}
        resource.post(hydrate=True)
        print(resource)

### Deleting the SAML default metadata configuration in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecuritySamlDefMetadata

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SecuritySamlDefMetadata()
        resource.delete()

## Classes

`class SecuritySamlDefMetadata (*args, **kwargs)`

  Allows interaction with SecuritySamlDefMetadata objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the SAML default metadata configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp/default-metadata`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the SAML default metadata configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp/default-metadata`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates the SAML default metadata configuration. Note that `common_name` is mutually exclusive with `serial_number` and `ca` in POST requests.

    ### Optional properties

    - `certificate`
    - `host`

    ### Learn more

    - `DOC /security/authentication/cluster/saml-sp/default-metadata`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class SecuritySamlDefMetadataSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecuritySamlDefMetadata object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `certificate: SecuritySamlDefMetadataCertificate GET POST`

    The certificate field of the security_saml_def_metadata.

  `host: str GET POST`

    The SAML service provider host.

  `links: SelfLink GET`

    The links field of the security_saml_def_metadata.

  `scope: str GET`

    Scope of the entity. Set to "cluster" for cluster owned objects and to "svm" for SVM owned objects.

    Valid choices:

    - cluster
    - svm